Module ast

Module ast 

Abstract Syntax Tree (AST) definitions for FiddlerScript.

This module contains all the node types that make up the parsed representation of a FiddlerScript program.

Structs

Block
A block of statements.
Program
A complete FiddlerScript program.

Enums

BinaryOp
Binary operators.
ElseClause
An else clause can be either a block or an else-if chain.
Expression
An expression in FiddlerScript.
Statement
A statement in FiddlerScript.
UnaryOp
Unary operators.