Interpreter for FiddlerScript.
This module contains the execution engine that evaluates the AST and produces runtime values.
Structs
- Interpreter
- The FiddlerScript interpreter.
Interpreter for FiddlerScript.
This module contains the execution engine that evaluates the AST and produces runtime values.