Module lexer

Module lexer 

Lexer (tokenizer) for FiddlerScript.

The lexer transforms source code into a stream of tokens that can be consumed by the parser.

Structs

Lexer
The lexer that tokenizes FiddlerScript source code.
Token
A token produced by the lexer.

Enums

TokenKind
The different kinds of tokens in FiddlerScript.