Module parser

Module parser 

Parser for FiddlerScript.

This module implements a recursive descent parser with Pratt parsing for expression precedence handling.

The parser transforms a token stream into an Abstract Syntax Tree (AST).

Structs

Parser
The parser for FiddlerScript.