Abstract Syntax Tree (AST) definitions for FiddlerScript.
This module contains all the node types that make up the parsed representation of a FiddlerScript program.
Structs
Enums
- Binary
Op - Binary operators.
- Else
Clause - An else clause can be either a block or an else-if chain.
- Expression
- An expression in FiddlerScript.
- Statement
- A statement in FiddlerScript.
- UnaryOp
- Unary operators.